searchData={"items":[{"type":"module","title":"Tracing","doc":"OpenTelemetry convenience module for often repeated patterns","ref":"Tracing.html"},{"type":"module","title":"Tracing with a span - Tracing","doc":"```\nrequire Tracing\n\nTracing.with_span \"this_is_my_span\" do\n  // do_work()\nend\n```\n\nAlso see `with_span_fn/2-3` for continued tracing within a spawned process.","ref":"Tracing.html#module-tracing-with-a-span"},{"type":"module","title":"Using the function decorator - Tracing","doc":"```\nuse Tracing\n\n@decorate with_span()\ndef do_work do\n  // do_more_work()\nend\n```","ref":"Tracing.html#module-using-the-function-decorator"},{"type":"function","title":"Tracing.add_event/2","doc":"Simple wrapper around `OpenTelemetry.Span.add_event/2`","ref":"Tracing.html#add_event/2"},{"type":"function","title":"Tracing.current_span/0","doc":"Returns the current span that can be used to add new events or attributes","ref":"Tracing.html#current_span/0"},{"type":"function","title":"Tracing.end_span/0","doc":"Simple wrapper around `OpenTelemetry.Tracer.end_span/0`","ref":"Tracing.html#end_span/0"},{"type":"function","title":"Tracing.extract/1","doc":"Helper function for propogating opentelemetry","ref":"Tracing.html#extract/1"},{"type":"function","title":"Tracing.extract_map/1","doc":"Helper function for propogating opentelemetry by using a map","ref":"Tracing.html#extract_map/1"},{"type":"function","title":"Tracing.inject/1","doc":"Helper function for propogating opentelemetry","ref":"Tracing.html#inject/1"},{"type":"function","title":"Tracing.inject_map/1","doc":"Helper function for propogating opentelemetry by using a map","ref":"Tracing.html#inject_map/1"},{"type":"function","title":"Tracing.monitor/1","doc":"Helper function to start Tracing.Monitor","ref":"Tracing.html#monitor/1"},{"type":"function","title":"Tracing.set_attributes/1","doc":"Simple wrapper around `OpenTelemetry.Span.set_attributes/2`","ref":"Tracing.html#set_attributes/1"},{"type":"function","title":"Tracing.set_current_span/1","doc":"Sets the current span to current_span() or what is provided","ref":"Tracing.html#set_current_span/1"},{"type":"function","title":"Tracing.setup/1","doc":"","ref":"Tracing.html#setup/1"},{"type":"function","title":"Tracing.setup_element/1","doc":"","ref":"Tracing.html#setup_element/1"},{"type":"function","title":"Tracing.trace_id/0","doc":"Returns hexadecimal string you can use to query in Honeycomb on `trace.trace_id`","ref":"Tracing.html#trace_id/0"},{"type":"macro","title":"Tracing.with_span/3","doc":"Simple wrapper around `OpenTelemetry.Tracer.with_span/3`","ref":"Tracing.html#with_span/3"},{"type":"macro","title":"Tracing.with_span_fn/3","doc":"Use this function when defining an anonymous function that will be used in _another process_.\nThis function will ensure that the span in the parent process is the parent span of the span in the spawned process.","ref":"Tracing.html#with_span_fn/3"},{"type":"macro","title":"Examples - Tracing.with_span_fn/3","doc":"```\nspawn(Tracing.with_span_fn(\"do something\", [key: :value], fn -> do_something() end))\n\nTask.start_link(Tracing.with_span_fn(\"do something\", fn -> do_something() end))\n\nTask.async_stream(things, Tracing.with_span_fn(\"do something\", fn thing -> do_something(thing) end))\n\nTask.start_link(Tracing.with_span_fn(&do_something/0))\n```","ref":"Tracing.html#with_span_fn/3-examples"},{"type":"macro","title":"Options - Tracing.with_span_fn/3","doc":"You can pass options which are forwarded to `OpenTelemetry.Tracer.with_span/3`. There is **one**\nspecial option that will also monitor the spawned process and close the span correctly.\n\n- `:monitor` - set to `true` to monitor the process","ref":"Tracing.html#with_span_fn/3-options"},{"type":"module","title":"Tracing.AWSTelemetry","doc":"","ref":"Tracing.AWSTelemetry.html"},{"type":"function","title":"Tracing.AWSTelemetry.handle_event/4","doc":"","ref":"Tracing.AWSTelemetry.html#handle_event/4"},{"type":"function","title":"Tracing.AWSTelemetry.setup/0","doc":"","ref":"Tracing.AWSTelemetry.html#setup/0"},{"type":"module","title":"Tracing.ChromicPDFTelemetry","doc":"","ref":"Tracing.ChromicPDFTelemetry.html"},{"type":"function","title":"Tracing.ChromicPDFTelemetry.handle_event/4","doc":"","ref":"Tracing.ChromicPDFTelemetry.html#handle_event/4"},{"type":"function","title":"Tracing.ChromicPDFTelemetry.setup/0","doc":"","ref":"Tracing.ChromicPDFTelemetry.html#setup/0"},{"type":"module","title":"Tracing.Decorator","doc":"","ref":"Tracing.Decorator.html"},{"type":"macro","title":"Tracing.Decorator.with_span/0","doc":"","ref":"Tracing.Decorator.html#with_span/0"},{"type":"macro","title":"Tracing.Decorator.with_span/1","doc":"","ref":"Tracing.Decorator.html#with_span/1"},{"type":"function","title":"Tracing.Decorator.with_span/2","doc":"","ref":"Tracing.Decorator.html#with_span/2"},{"type":"function","title":"Tracing.Decorator.with_span/3","doc":"","ref":"Tracing.Decorator.html#with_span/3"},{"type":"module","title":"Tracing.LiveviewTelemetry","doc":"","ref":"Tracing.LiveviewTelemetry.html"},{"type":"function","title":"Tracing.LiveviewTelemetry.handle_event/4","doc":"","ref":"Tracing.LiveviewTelemetry.html#handle_event/4"},{"type":"function","title":"Tracing.LiveviewTelemetry.setup/0","doc":"","ref":"Tracing.LiveviewTelemetry.html#setup/0"},{"type":"module","title":"Tracing.Monitor","doc":"","ref":"Tracing.Monitor.html"},{"type":"function","title":"Tracing.Monitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Tracing.Monitor.html#child_spec/1"},{"type":"function","title":"Tracing.Monitor.init/1","doc":"","ref":"Tracing.Monitor.html#init/1"},{"type":"function","title":"Tracing.Monitor.monitor/1","doc":"Start monitoring the given span. If the span is not set, it defaults to `Tracing.current_span()`","ref":"Tracing.Monitor.html#monitor/1"},{"type":"function","title":"Tracing.Monitor.start_link/1","doc":"","ref":"Tracing.Monitor.html#start_link/1"},{"type":"module","title":"Tracing.ObanTelemetry","doc":"Handles telemetry and events for Oban workers.\n\nAllows a function `reportable?/1` to be set in an oban worker to define in which case exceptions should be reported or\nnot. If `reportable?/1` does not exist, all errors will be reported.","ref":"Tracing.ObanTelemetry.html"},{"type":"module","title":"Example - Tracing.ObanTelemetry","doc":"```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    # ...\n    Tracing.setup([:oban])\n    Supervisor.start_link([], [name: MyApp.Supervisor])\n  end\nend\n\ndefmodule MyApp.ObanWorker do\n  use Oban.Worker, queue: \"webhooks\"\n\n  @impl Oban.Worker\n  def perform(args) do\n    # execute\n  end\n\n  def reportable?(meta) do\n    meta.attempt >= 3\n  end\nend\n```","ref":"Tracing.ObanTelemetry.html#module-example"},{"type":"function","title":"Tracing.ObanTelemetry.handle_event/4","doc":"","ref":"Tracing.ObanTelemetry.html#handle_event/4"},{"type":"function","title":"Tracing.ObanTelemetry.setup/0","doc":"","ref":"Tracing.ObanTelemetry.html#setup/0"},{"type":"module","title":"Tracing.Sampler","doc":"","ref":"Tracing.Sampler.html"},{"type":"module","title":"Tracing.Telemetry","doc":"","ref":"Tracing.Telemetry.html"},{"type":"function","title":"Tracing.Telemetry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Tracing.Telemetry.html#child_spec/1"},{"type":"function","title":"Tracing.Telemetry.metrics/0","doc":"","ref":"Tracing.Telemetry.html#metrics/0"},{"type":"function","title":"Tracing.Telemetry.start_link/1","doc":"","ref":"Tracing.Telemetry.html#start_link/1"},{"type":"extras","title":"Tracing","doc":"# Tracing\n\nTracing is a library that contains some standardized telemetry modules with ease of use. It allows control over which modules\nshould be activated.","ref":"readme.html"},{"type":"extras","title":"Installation - Tracing","doc":"The package can be installed by adding `tracing` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tracing, \"~> 0.1.3\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc).","ref":"readme.html#installation"},{"type":"extras","title":"Setup - Tracing","doc":"Tracing relies on `Tracing.Monitor` that should be added to the children list in your `Application.start/2`.\n\nAdd `Tracing.setup/1` to `Application.start/2` too with the modules you want to enable telemetry for.\n\nAlso `Tracing.Telemetry` can be started. The defaults are an empty list of measurements for a period of `10_000` ms. Both can be overridden.\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      Tracing.Monitor,\n      Tracing.Telemetry,\n      # or\n      {Tracing.Telemetry, measurements: [], period: 15_000},\n      ...\n    ]\n    opts = [...]\n\n    Tracing.setup([:phoenix, :liveview, :oban, :aws, :chromic_pdf])\n\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"readme.html#setup"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}